@@ -261,9 +261,9 @@ void NormalizedRect::transform(const QTransform &matrix)
     bottom = rect.bottom();
 }
 
-uint Okular::qHash(const NormalizedRect &r, uint seed)
+size_t Okular::qHash(const NormalizedRect &r, size_t seed)
 {
-    return ::qHash(r.bottom, ::qHash(r.right, ::qHash(r.top, ::qHash(r.left, seed))));
+    return ::qHashMulti(seed, r.bottom, r.right, r.top, r.left);
 }
 
 QDebug operator<<(QDebug str, const Okular::NormalizedRect &r)
