@@ -160,8 +160,8 @@ void FontExtractionThread::run()
     for (int i = -1; i < mNumOfPages && mGoOn; ++i) {
         const FontInfo::List list = mGenerator->fontsForPage(i);
         for (const FontInfo &fi : list) {
-            emit gotFont(fi);
+            Q_EMIT gotFont(fi);
         }
-        emit progress(i);
+        Q_EMIT progress(i);
     }
 }
