@@ -55,10 +55,12 @@ public:
         , clicked(false)
         , xscale(1.0)
         , yscale(1.0)
+        , hoverIconName {engineElement.attribute(QStringLiteral("hoverIcon"))}
+        , iconName {m_annotElement.attribute(QStringLiteral("icon"))}
+        , pagewidth(1.0)
+        , pageheight(1.0)
     {
         // parse engine specific attributes
-        hoverIconName = engineElement.attribute(QStringLiteral("hoverIcon"));
-        iconName = m_annotElement.attribute(QStringLiteral("icon"));
         if (m_annotElement.attribute(QStringLiteral("type")) == QLatin1String("Stamp") && !iconName.simplified().isEmpty()) {
             hoverIconName = iconName;
         }
@@ -72,7 +74,7 @@ public:
 
         // create engine objects
         if (!hoverIconName.simplified().isEmpty()) {
-            pixmap = Okular::AnnotationUtils::loadStamp(hoverIconName, size);
+            pixmap = Okular::AnnotationUtils::loadStamp(hoverIconName, QSize(size, size));
         }
     }
 
@@ -327,9 +329,9 @@ private:
     bool center;
 };
 
-#if HAVE_NEW_SIGNATURE_API
 class PickPointEngineSignature : public PickPointEngine
 {
+#if HAVE_NEW_SIGNATURE_API
 public:
     explicit PickPointEngineSignature(SignaturePartUtils::SigningInformation *info)
         : PickPointEngine({})
@@ -362,6 +364,13 @@ public:
         const QString datetime = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss t"));
         const QString signatureText = i18n("Signed by: %1\n\nDate: %2", certSubjectCommonName, datetime);
 
+        m_creationCompleted = false;
+        clicked = false;
+        // safety check
+        if (!ann) {
+            return QList<Okular::Annotation *>();
+        }
+
         ann->setLeftText(certSubjectCommonName);
         ann->setText(signatureText);
         ann->setImagePath(m_signingInformation->backgroundImagePath);
@@ -372,14 +381,6 @@ public:
         ann->setFontSize(0);
 #endif
 
-        m_creationCompleted = false;
-        clicked = false;
-
-        // safety check
-        if (!ann) {
-            return QList<Okular::Annotation *>();
-        }
-
         // set the bounding rectangle, and make sure that the newly created
         // annotation lies within the page by translating it if necessary
         if (rect.right > 1) {
@@ -410,10 +411,7 @@ private:
 
     bool m_aborted;
     SignaturePartUtils::SigningInformation *m_signingInformation;
-};
 #else
-class PickPointEngineSignature : public PickPointEngine
-{
 public:
     PickPointEngineSignature(Okular::Document *document, PageView *pageView, SignaturePartUtils::SigningInformation *info)
         : PickPointEngine({})
@@ -476,7 +474,7 @@ public:
         return m_aborted;
     }
 
-    bool sign(const QString &newFilePath)
+    std::pair<Okular::SigningResult, QString> sign(const QString &newFilePath)
     {
         Okular::NewSignatureData data;
         data.setCertNickname(m_signingInformation->certificate->nickName());
@@ -504,8 +502,8 @@ private:
     bool m_startOver;
     bool m_aborted;
     SignaturePartUtils::SigningInformation *m_signingInformation;
-};
 #endif
+};
 
 /** @short PolyLineEngine */
 class PolyLineEngine : public AnnotatorEngine
@@ -720,10 +718,10 @@ public:
             return oldrect;
         } else if (type == Move) {
             if (item()) {
-                const QPoint start((int)(lastPoint.x * item()->uncroppedWidth()), (int)(lastPoint.y * item()->uncroppedHeight()));
-                const QPoint end((int)(nX * item()->uncroppedWidth()), (int)(nY * item()->uncroppedHeight()));
+                const QPoint selectionStart((int)(lastPoint.x * item()->uncroppedWidth()), (int)(lastPoint.y * item()->uncroppedHeight()));
+                const QPoint selectionEnd((int)(nX * item()->uncroppedWidth()), (int)(nY * item()->uncroppedHeight()));
                 selection.reset();
-                std::unique_ptr<Okular::RegularAreaRect> newselection(m_pageView->textSelectionForItem(item(), start, end));
+                std::unique_ptr<Okular::RegularAreaRect> newselection = m_pageView->textSelectionForItem(item(), selectionStart, selectionEnd);
                 if (newselection && !newselection->isEmpty()) {
                     const QList<QRect> geom = newselection->geometry((int)xScale, (int)yScale);
                     QRect newrect;
@@ -1118,7 +1116,7 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
         }
 
         if (signatureMode()) {
-            auto signEngine = static_cast<PickPointEngineSignature *>(m_engine);
+            const auto signEngine = static_cast<PickPointEngineSignature *>(m_engine);
 
 #if !HAVE_NEW_SIGNATURE_API
             if (signEngine->userWantsToStartOver()) {
@@ -1130,11 +1128,28 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
                 const QString newFilePath = SignaturePartUtils::getFileNameForNewSignedFile(m_pageView, m_document);
 
                 if (!newFilePath.isEmpty()) {
-                    const bool success = static_cast<PickPointEngineSignature *>(m_engine)->sign(newFilePath);
-                    if (success) {
-                        Q_EMIT requestOpenNewlySignedFile(newFilePath, m_lockedItem->pageNumber() + 1);
-                    } else {
-                        KMessageBox::error(m_pageView, i18nc("%1 is a file path", "Could not sign. Invalid certificate password or could not write to '%1'", newFilePath));
+                    const std::pair<Okular::SigningResult, QString> result = static_cast<PickPointEngineSignature *>(m_engine)->sign(newFilePath);
+                    switch (result.first) {
+                    case Okular::SigningSuccess: {
+                        Q_EMIT m_pageView->requestOpenNewlySignedFile(newFilePath, m_lockedItem->pageNumber() + 1);
+                        break;
+                    }
+                    case Okular::FieldAlreadySigned: // We should not end up here
+                    case Okular::KeyMissing:         // unless the user modified the key store after opening the dialog, this should not happen
+                    case Okular::InternalSigningError:
+                        KMessageBox::detailedError(m_pageView, errorString(result.first, static_cast<int>(result.first)), result.second);
+                        break;
+                    case Okular::GenericSigningError:
+                        KMessageBox::detailedError(m_pageView, errorString(result.first, newFilePath), result.second);
+                        break;
+                    case Okular::UserCancelled:
+                        break;
+                    case Okular::BadPassphrase:
+                        KMessageBox::detailedError(m_pageView, errorString(result.first, {}), result.second);
+                        break;
+                    case Okular::SignatureWriteFailed:
+                        KMessageBox::detailedError(m_pageView, errorString(result.first, newFilePath), result.second);
+                        break;
                     }
                 }
                 // Exit the signature mode.
@@ -1539,14 +1554,14 @@ QPixmap PageViewAnnotator::makeToolPixmap(const QDomElement &toolElement)
         p.drawRect(2, 7, 21, 14);
     } else if (annotType == QLatin1String("squiggly")) {
         QPen pen(engineColor, 1);
-        pen.setDashPattern(QVector<qreal>() << 1 << 1);
+        pen.setDashPattern(QList<qreal>() << 1 << 1);
         p.setPen(pen);
         p.drawLine(1, 13, 16, 13);
         p.drawLine(2, 14, 15, 14);
         p.drawLine(0, 20, 19, 20);
         p.drawLine(1, 21, 18, 21);
     } else if (annotType == QLatin1String("stamp")) {
-        QPixmap stamp = Okular::AnnotationUtils::loadStamp(icon, 16, false /* keepAspectRatio */);
+        QPixmap stamp = Okular::AnnotationUtils::loadStamp(icon, QSize(16, 16), Qt::IgnoreAspectRatio);
         p.setRenderHint(QPainter::Antialiasing);
         p.drawPixmap(16, 14, stamp);
     } else if (annotType == QLatin1String("straight-line")) {
