@@ -29,7 +29,7 @@ public:
     ~SignaturePanel() override;
 
     // inherited from DocumentObserver
-    void notifySetup(const QVector<Okular::Page *> &pages, int setupFlags) override;
+    void notifySetup(const QList<Okular::Page *> &pages, int setupFlags) override;
 
     void setPageView(PageView *pv);
 
