@@ -21,11 +21,11 @@ public:
     void stopAllSpeechs();
     void pauseResumeSpeech();
 
-public slots:
+public Q_SLOTS:
     void slotSpeechStateChanged(QTextToSpeech::State state);
     void slotConfigChanged();
 
-signals:
+Q_SIGNALS:
     void isSpeaking(bool speaking);
     void canPauseOrResume(bool speakingOrPaused);
 
